import { RequestService } from '../../RequestService';
import { PaginationOptions, LibrariesIOResult, Project, RepositoryWithDependencies } from '../../interfaces/';
export declare class GitHubRepositoryAPI {
    private readonly requestService;
    constructor(requestService: RequestService);
    /**
     * Get a info for a repository. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepository(repositoryOwner: string, repositoryName: string): Promise<LibrariesIOResult<RepositoryWithDependencies>>;
    /**
     * Get a list of dependencies for a repositories. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository-dependencies
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepositoryWithDependencies(repositoryOwner: string, repositoryName: string): Promise<LibrariesIOResult<RepositoryWithDependencies>>;
    /**
     * Get a list of packages referencing the given repository.
     * @see https://libraries.io/api#repository-projects
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     * @param options Pagination Options
     */
    getProjects(repositoryOwner: string, repositoryName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
}
