"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Endpoints_1 = require("../../Endpoints");
var GitHubUserAPI = /** @class */ (function () {
    function GitHubUserAPI(requestService) {
        this.requestService = requestService;
    }
    /**
     * Get information for a given user or organization.
     * @see https://libraries.io/api#user
     * @param userName The username
     */
    GitHubUserAPI.prototype.getUser = function (userName) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.user(userName);
        return this.requestService.get(endpoint);
    };
    /**
     * Get repositories owned by a user.
     * @see https://libraries.io/api#user-repositories
     * @param userName The username
     * @param options Pagination options
     */
    GitHubUserAPI.prototype.getRepositories = function (userName, options) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
        return this.requestService.get(endpoint, options);
    };
    /**
     * Get a list of packages referencing the given user's repositories.
     * @see https://libraries.io/api#user-projects
     * @param userName The username
     * @param options Pagination options
     */
    GitHubUserAPI.prototype.getProjects = function (userName, options) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
        return this.requestService.get(endpoint, options);
    };
    /**
     * Get a list of packages that the given user has contributed to.
     * @see https://libraries.io/api#user-project-contributions
     * @param userName The username
     * @param options Pagination options
     */
    GitHubUserAPI.prototype.getContributedProjects = function (userName, options) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.contributedProjects(userName);
        return this.requestService.get(endpoint, options);
    };
    /**
     * Get a list of repositories that the given user has contributed to.
     * @see https://libraries.io/api#user-repository-contributions
     * @param userName The username
     * @param options Pagination options
     */
    GitHubUserAPI.prototype.getContributedRepositories = function (userName, options) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
        return this.requestService.get(endpoint, options);
    };
    /**
     * Get a list of unique packages that the given user's repositories list as a dependency. Ordered by frequency of use in those repositories.
     * @see https://libraries.io/api#user-dependencies
     * @param userName The username
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param options Pagination options
     */
    GitHubUserAPI.prototype.getDependencies = function (userName, platformOrOptions, options) {
        var endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
        var parameters = {};
        if (platformOrOptions) {
            if (typeof platformOrOptions === 'string') {
                parameters = __assign({ platform: platformOrOptions }, options);
            }
            else {
                parameters = platformOrOptions;
            }
        }
        return this.requestService.get(endpoint, parameters);
    };
    return GitHubUserAPI;
}());
exports.GitHubUserAPI = GitHubUserAPI;
//# sourceMappingURL=GitHubUserAPI.js.map