import { RequestService } from '../RequestService';
import { LibrariesIOHeaders, LibrariesIOResult, PaginationOptions, PreReleaseOptions, Subscription } from '../interfaces/';
export declare class UserAPI {
    private readonly requestService;
    constructor(requestService: RequestService);
    /**
     * Check if a users is subscribed to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-show
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSubscription(platform: string, projectName: string): Promise<LibrariesIOResult<Subscription | null>>;
    /**
     * List packages that a user is subscribed to recieved notifications about new releases.
     * @see https://libraries.io/api#subscriptions-index
     * @param options Pagination options
     */
    getAllSubscriptions(options?: PaginationOptions): Promise<LibrariesIOResult<Subscription[]>>;
    /**
     * Subscribe to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-create
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    subscribe(platform: string, projectName: string, options?: PreReleaseOptions): Promise<LibrariesIOResult<Subscription>>;
    /**
     * Stop receiving release notifications from a project.
     * @see https://libraries.io/api#subscriptions-destroy
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    unsubscribe(platform: string, projectName: string): Promise<LibrariesIOHeaders>;
    /**
     * Update the options for a subscription.
     * @see https://libraries.io/api#subscriptions-update
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    updateSubscription(platform: string, projectName: string, options?: PreReleaseOptions): Promise<LibrariesIOResult<Subscription>>;
}
