"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Endpoints_1 = require("../Endpoints");
var UserAPI = /** @class */ (function () {
    function UserAPI(requestService) {
        this.requestService = requestService;
    }
    /**
     * Check if a users is subscribed to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-show
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    UserAPI.prototype.getSubscription = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.requestService.get(endpoint);
    };
    /**
     * List packages that a user is subscribed to recieved notifications about new releases.
     * @see https://libraries.io/api#subscriptions-index
     * @param options Pagination options
     */
    UserAPI.prototype.getAllSubscriptions = function (options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions();
        return this.requestService.get(endpoint, options);
    };
    /**
     * Subscribe to receive notifications about new releases of a project.
     * @see https://libraries.io/api#subscriptions-create
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    UserAPI.prototype.subscribe = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.requestService.post(endpoint, options);
    };
    /**
     * Stop receiving release notifications from a project.
     * @see https://libraries.io/api#subscriptions-destroy
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    UserAPI.prototype.unsubscribe = function (platform, projectName) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.requestService.delete(endpoint);
    };
    /**
     * Update the options for a subscription.
     * @see https://libraries.io/api#subscriptions-update
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Subscription options
     */
    UserAPI.prototype.updateSubscription = function (platform, projectName, options) {
        var endpoint = Endpoints_1.Endpoint.subscriptions(platform, projectName);
        return this.requestService.put(endpoint, options);
    };
    return UserAPI;
}());
exports.UserAPI = UserAPI;
//# sourceMappingURL=UserAPI.js.map